@@ -84,19 +84,19 @@ print.limitmeta <- function(x,
                             ...) {
   
   
-  ##
-  ##
-  ## (1) Check for summary.limitmeta object
-  ##
-  ##
+  #
+  #
+  # (1) Check for summary.limitmeta object
+  #
+  #
   chkclass(x, "limitmeta")
   
   
-  ##
-  ##
-  ## (2) Check and set other arguments
-  ##
-  ##
+  #
+  #
+  # (2) Check and set other arguments
+  #
+  #
   chknumeric(digits, min = 0, length = 1)
   chknumeric(digits.tau2, min = 0, length = 1)
   chknumeric(digits.stat, min = 0, length = 1)
@@ -107,11 +107,11 @@ print.limitmeta <- function(x,
   chklogical(scientific.pval)
   chklogical(print.Rb)
   chklogical(warn.backtransf)
-  ##
-  is.prop <- is.prop(x$sm)
-  is.rate <- is.rate(x$sm)
-  ##
-  if (!is.prop)
+  #
+  is_prop <- is_prop(x$sm)
+  is_rate <- is_rate(x$sm)
+  #
+  if (!is_prop)
     pscale <- 1
   if (!is.null(pscale))
     chknumeric(pscale, length = 1)
@@ -121,7 +121,7 @@ print.limitmeta <- function(x,
     warning("Argument 'pscale' set to 1 as argument 'backtransf' is FALSE.")
     pscale <- 1
   }
-  if (!is.rate)
+  if (!is_rate)
     irscale <- 1
   if (!is.null(irscale))
     chknumeric(irscale, length = 1)
@@ -131,44 +131,44 @@ print.limitmeta <- function(x,
     warning("Argument 'irscale' set to 1 as argument 'backtransf' is FALSE.")
     irscale <- 1
   }
-  ##
-  ## Additional arguments / checks for metacont objects
-  ##
+  #
+  # Additional arguments / checks for metacont objects
+  #
   cl <- class(x)[1]
   addargs <- names(list(...))
-  ##
+  #
   fun <- "print.limitmeta"
-  ##
+  #
   warnarg("logscale", addargs, fun, otherarg = "backtransf")
   
   
-  ##
-  ##
-  ## (3) Some additional settings
-  ##
-  ##
+  #
+  #
+  # (3) Some additional settings
+  #
+  #
   ci.lab <- paste(round(100 * x$level.ma, 1), "%-CI", sep = "")
-  ##  
+  #  
   k <- x$k
   sm <- x$sm
-  ##
+  #
   if (is.null(x$df.Q))
     df.Q <- k - 1
   else
     df.Q <- x$df.Q
-  ##
+  #
   sm.lab <- sm
-  ##
+  #
   if (backtransf) {
     if (sm == "ZCOR")
       sm.lab <- "COR"
-    else if (is.prop) {
+    else if (is_prop) {
       if (pscale == 1)
         sm.lab <- "proportion"
       else
         sm.lab <- "events"
     }
-    else if (is.rate) {
+    else if (is_rate) {
       if (irscale == 1)
         sm.lab <- "rate"
       else
@@ -176,74 +176,71 @@ print.limitmeta <- function(x,
     }
   }
   else
-    if (is.relative.effect(sm))
+    if (is_relative_effect(sm))
       sm.lab <- paste("log", sm, sep = "")
   
   
-  ##
-  ##
-  ## (4) Set and backtransform results of meta-analysis
-  ##
-  ##
+  #
+  #
+  # (4) Set and backtransform results of meta-analysis
+  #
+  #
   TEs <- c(x$TE.adjust, x$TE.random)
   lower <- c(x$lower.adjust, x$lower.random)
   upper <- c(x$upper.adjust, x$upper.random)
-  ##
+  #
   if (backtransf) {
     if (inherits(x$x, "metarate"))
       harmonic.mean <- 1 / mean(1 / x$x$time)
     else
       harmonic.mean <- 1 / mean(1 / x$x$n)
-    ##
-    TEs   <- backtransf(TEs, sm, "mean",
-                               harmonic.mean, warn = warn.backtransf)
-    lower <- backtransf(lower, sm, "lower",
-                               harmonic.mean, warn = warn.backtransf)
-    upper <- backtransf(upper, sm, "upper",
-                               harmonic.mean, warn = warn.backtransf)
+    #
+    TEs   <- backtransf(TEs, sm, harmonic.mean)
+    lower <- backtransf(lower, sm, harmonic.mean)
+    upper <- backtransf(upper, sm, harmonic.mean)
   }
-  ##
-  ## Apply argument 'pscale' to proportions and 'irscale' to rates
-  ##
-  if (is.prop | is.rate) {
-    if (is.prop)
+  #
+  # Apply argument 'pscale' to proportions and 'irscale' to rates
+  #
+  if (is_prop | is_rate) {
+    if (is_prop)
       scale <- pscale
-    else if (is.rate)
+    else if (is_rate)
       scale <- irscale
-    ##
+    #
     TEs    <- scale * TEs
     lower <- scale * lower
     upper <- scale * upper
   }
-  ##
-  ## Round and round ...
-  ##
+  #
+  # Round and round ...
+  #
   TEs   <- round(TEs, digits)
   lower <- round(lower, digits)
   upper <- round(upper, digits)
-  ##
+  #
   pvals <- c(x$pval.adjust, x$pval.random)
   statistics <- round(c(x$statistic.adjust, x$statistic.random), digits.stat)
-  ##
+  #
   I2 <- round(100 * x$x$I2, digits.I2)
   lowI2 <- round(100 * x$x$lower.I2, digits.I2)
   uppI2 <- round(100 * x$x$upper.I2, digits.I2)
-  ##
+  #
   Rb <- round(100 * x$x$Rb, digits.I2)
   lowRb <- round(100 * x$x$lower.Rb, digits.I2)
   uppRb <- round(100 * x$x$upper.Rb, digits.I2)
-  ##
+  #
   G2 <- round(100 * x$G.squared, digits.I2)
   
   
-  ##
-  ##
-  ## (5) Print result for meta-analysis
-  ##
-  ##
+  #
+  #
+  # (5) Print result for meta-analysis
+  #
+  #
   if (header)
     crtitle(x)
-  ##
+  #
   res <- cbind(c("Adjusted estimate",
                  "Unadjusted estimate"),
                formatN(TEs, digits, "NA", big.mark = big.mark),
@@ -253,25 +250,25 @@ print.limitmeta <- function(x,
                formatPT(pvals, digits = digits.pval,
                         scientific = scientific.pval)
                )
-  ##
+  #
   dimnames(res) <- list(rep("", dim(res)[[1]]),
                         c("Random effects model",
                           sm.lab, ci.lab, "z", "pval"))
-  ##
+  #
   cat("Result of limit meta-analysis:\n\n")
-  ##
+  #
   prmatrix(res, quote = FALSE, right = TRUE)
-  ##  
+  #  
   if (!is.na(x$tau)) {
-    ##
+    #
     cat(paste("\nQuantifying heterogeneity:\n",
-              ##
+              #
               formatPT(x$tau^2,
                        lab = TRUE, labval = gs("text.tau2"),
                        digits = digits.tau2,
                        big.mark = big.mark,
                        lab.NA = "NA"),
-              ##
+              #
               paste("; ",
                     "I^2 = ",
                     if (is.nan(I2)) "NA" else paste(formatN(I2, digits.I2),
@@ -309,26 +306,26 @@ print.limitmeta <- function(x,
   Qd <- function(Q, df)
     data.frame(Q = round(Q, 2), df = df,
                p = 1 - pchisq(Q, df = df))
-  ##
+  #
   Qds <- rbind(Qd(x$Q, k - 1),
                Qd(x$Q.small, 1),
                Qd(x$Q.resid, k - 2))
   Qds$Q  <- format(Qds$Q)
   Qds$df <- format(Qds$df)
   Qds$p  <- formatPT(Qds$p, digits = digits.pval, scientific = scientific.pval)
-  ##
+  #
   Qd1 <- Qds[1, ]
   Qd2 <- Qds[2, ]
   Qd3 <- Qds[3, ]
-  ##
+  #
   dimnames(Qd1) <- list("", c("Q", "d.f.", "p-value"))
   cat("\nTest of heterogeneity:\n")
   prmatrix(Qd1, quote = FALSE, right = TRUE, ...)
-  ##
+  #
   dimnames(Qd2) <- list("", c("Q-Q'", "d.f.", "p-value"))
   cat("\nTest of small-study effects:\n")
   prmatrix(Qd2, quote = FALSE, right = TRUE, ...)
-  ##
+  #
   dimnames(Qd3) <- list("", c("Q'", "d.f.", "p-value"))
   cat("\nTest of residual heterogeneity beyond small-study effects:\n")
   prmatrix(Qd3, quote = FALSE, right = TRUE, ...)
@@ -336,16 +333,14 @@ print.limitmeta <- function(x,
   
   imeth <- charmatch(tolower(x$method.adjust),
                      c("beta0", "betalim", "mulim"), nomatch = NA)
-  ##
-  if(is.na(imeth))
+  #
+  if (is.na(imeth))
     stop("Argument 'method.adjust' should be \"beta0\", \"betalim\", or \"mulim\"")
-  ##
-  method.adjust.detail <- c("- expectation (beta0)",
-                            "- including bias parameter (beta-lim)",
-                            "- excluding bias parameter (mu-lim)")[imeth]
-  ##
-  cat("\nDetails on adjustment method:\n",
-      method.adjust.detail,
+  #
+  cat("\nAdjustment method: ",
+      c("expectation (beta0)",
+        "including bias parameter (beta-lim)",
+        "excluding bias parameter (mu-lim)")[imeth],
       "\n", sep = "")
   
   
